@@ -5,9 +5,8 @@ from borgmatic.actions import repo_delete as module
 
 def test_run_repo_delete_does_not_raise():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').and_return(True)
     flexmock(module.borgmatic.actions.arguments).should_receive('update_arguments').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.borg.repo_delete).should_receive('delete_repository')
 
@@ -24,9 +23,8 @@ def test_run_repo_delete_does_not_raise():
 
 def test_run_repo_delete_with_cache_only_does_not_raise():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').and_return(True)
     flexmock(module.borgmatic.actions.arguments).should_receive('update_arguments').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.borg.repo_delete).should_receive('delete_repository')
 
