@@ -5,7 +5,6 @@ from borgmatic.actions import repo_list as module
 
 def test_run_repo_list_does_not_raise():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').and_return(True)
     flexmock(module.borgmatic.borg.repo_list).should_receive('list_repository')
     repo_list_arguments = flexmock(repository=flexmock(), json=False)
 
@@ -18,15 +17,14 @@ def test_run_repo_list_does_not_raise():
             global_arguments=flexmock(),
             local_path=None,
             remote_path=None,
-        )
+        ),
     )
 
 
 def test_run_repo_list_produces_json():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.validate).should_receive('repositories_match').and_return(True)
     flexmock(module.borgmatic.borg.repo_list).should_receive('list_repository').and_return(
-        flexmock()
+        flexmock(),
     )
     parsed_json = flexmock()
     flexmock(module.borgmatic.actions.json).should_receive('parse_json').and_return(parsed_json)
@@ -41,5 +39,5 @@ def test_run_repo_list_produces_json():
             global_arguments=flexmock(),
             local_path=None,
             remote_path=None,
-        )
+        ),
     ) == [parsed_json]
