@@ -41,7 +41,7 @@ def test_change_passphrase_calls_borg_with_required_flags():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
@@ -54,7 +54,7 @@ def test_change_passphrase_calls_borg_with_local_path():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg1',
     )
 
@@ -64,7 +64,9 @@ def test_change_passphrase_calls_borg_using_exit_codes():
     borg_exit_codes = flexmock()
     config = {'borg_exit_codes': borg_exit_codes}
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', 'repo'), config=config, borg_exit_codes=borg_exit_codes
+        ('borg', 'key', 'change-passphrase', 'repo'),
+        config=config,
+        borg_exit_codes=borg_exit_codes,
     )
 
     module.change_passphrase(
@@ -72,14 +74,14 @@ def test_change_passphrase_calls_borg_using_exit_codes():
         config=config,
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
 def test_change_passphrase_calls_borg_with_remote_path_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', '--remote-path', 'borg1', 'repo')
+        ('borg', 'key', 'change-passphrase', '--remote-path', 'borg1', 'repo'),
     )
 
     module.change_passphrase(
@@ -87,7 +89,7 @@ def test_change_passphrase_calls_borg_with_remote_path_flags():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
         remote_path='borg1',
     )
 
@@ -96,7 +98,8 @@ def test_change_passphrase_calls_borg_with_umask_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     config = {'umask': '0770'}
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', '--umask', '0770', 'repo'), config=config
+        ('borg', 'key', 'change-passphrase', '--umask', '0770', 'repo'),
+        config=config,
     )
 
     module.change_passphrase(
@@ -104,20 +107,24 @@ def test_change_passphrase_calls_borg_with_umask_flags():
         config=config,
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
 def test_change_passphrase_calls_borg_with_log_json_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
-    insert_execute_command_mock(('borg', 'key', 'change-passphrase', '--log-json', 'repo'))
+    config = {'log_json': True}
+    insert_execute_command_mock(
+        ('borg', 'key', 'change-passphrase', '--log-json', 'repo'),
+        config=config,
+    )
 
     module.change_passphrase(
         repository_path='repo',
-        config={},
+        config=config,
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=True),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
@@ -125,7 +132,8 @@ def test_change_passphrase_calls_borg_with_lock_wait_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     config = {'lock_wait': '5'}
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', '--lock-wait', '5', 'repo'), config=config
+        ('borg', 'key', 'change-passphrase', '--lock-wait', '5', 'repo'),
+        config=config,
     )
 
     module.change_passphrase(
@@ -133,7 +141,24 @@ def test_change_passphrase_calls_borg_with_lock_wait_flags():
         config=config,
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
+    )
+
+
+def test_change_passphrase_calls_borg_with_extra_borg_options():
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+    config = {'extra_borg_options': {'key_change_passphrase': '--extra "value with space"'}}
+    insert_execute_command_mock(
+        ('borg', 'key', 'change-passphrase', '--extra', 'value with space', 'repo'),
+        config=config,
+    )
+
+    module.change_passphrase(
+        repository_path='repo',
+        config=config,
+        local_borg_version='1.2.3',
+        change_passphrase_arguments=flexmock(),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
@@ -147,14 +172,14 @@ def test_change_passphrase_with_log_info_calls_borg_with_info_parameter():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
 def test_change_passphrase_with_log_debug_calls_borg_with_debug_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', '--debug', '--show-rc', 'repo')
+        ('borg', 'key', 'change-passphrase', '--debug', '--show-rc', 'repo'),
     )
     insert_logging_mock(logging.DEBUG)
 
@@ -163,7 +188,7 @@ def test_change_passphrase_with_log_debug_calls_borg_with_debug_flags():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
@@ -177,14 +202,15 @@ def test_change_passphrase_with_dry_run_skips_borg_call():
         config={},
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(paper=False, qr_html=False, path=None),
-        global_arguments=flexmock(dry_run=True, log_json=False),
+        global_arguments=flexmock(dry_run=True),
     )
 
 
 def test_change_passphrase_calls_borg_without_passphrase():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(
-        ('borg', 'key', 'change-passphrase', 'repo'), config={'option': 'foo'}
+        ('borg', 'key', 'change-passphrase', 'repo'),
+        config={'option': 'foo'},
     )
 
     module.change_passphrase(
@@ -196,7 +222,7 @@ def test_change_passphrase_calls_borg_without_passphrase():
         },
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
 
 
@@ -214,5 +240,5 @@ def test_change_passphrase_calls_borg_with_working_directory():
         config=config,
         local_borg_version='1.2.3',
         change_passphrase_arguments=flexmock(),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        global_arguments=flexmock(dry_run=False),
     )
