@@ -23,13 +23,13 @@ def test_extract_last_archive_dry_run_calls_borg_with_last_archive():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(('borg', 'extract', '--dry-run', 'repo::archive'))
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -42,7 +42,7 @@ def test_extract_last_archive_dry_run_without_any_archives_should_not_raise():
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -53,13 +53,13 @@ def test_extract_last_archive_dry_run_with_log_info_calls_borg_with_info_paramet
     insert_execute_command_mock(('borg', 'extract', '--dry-run', '--info', 'repo::archive'))
     insert_logging_mock(logging.INFO)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -68,17 +68,17 @@ def test_extract_last_archive_dry_run_with_log_info_calls_borg_with_info_paramet
 def test_extract_last_archive_dry_run_with_log_debug_calls_borg_with_debug_parameter():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
-        ('borg', 'extract', '--dry-run', '--debug', '--show-rc', '--list', 'repo::archive')
+        ('borg', 'extract', '--dry-run', '--debug', '--show-rc', '--list', 'repo::archive'),
     )
     insert_logging_mock(logging.DEBUG)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -88,13 +88,13 @@ def test_extract_last_archive_dry_run_calls_borg_via_local_path():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(('borg1', 'extract', '--dry-run', 'repo::archive'))
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
         local_path='borg1',
@@ -105,16 +105,17 @@ def test_extract_last_archive_dry_run_calls_borg_using_exit_codes():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     borg_exit_codes = flexmock()
     insert_execute_command_mock(
-        ('borg', 'extract', '--dry-run', 'repo::archive'), borg_exit_codes=borg_exit_codes
+        ('borg', 'extract', '--dry-run', 'repo::archive'),
+        borg_exit_codes=borg_exit_codes,
     )
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={'borg_exit_codes': borg_exit_codes},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -123,16 +124,16 @@ def test_extract_last_archive_dry_run_calls_borg_using_exit_codes():
 def test_extract_last_archive_dry_run_calls_borg_with_remote_path_flags():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
-        ('borg', 'extract', '--dry-run', '--remote-path', 'borg1', 'repo::archive')
+        ('borg', 'extract', '--dry-run', '--remote-path', 'borg1', 'repo::archive'),
     )
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
         remote_path='borg1',
@@ -143,13 +144,13 @@ def test_extract_last_archive_dry_run_calls_borg_with_log_json_flag():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(('borg', 'extract', '--dry-run', '--log-json', 'repo::archive'))
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
-        config={},
+        config={'log_json': True},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=True),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=None,
     )
@@ -158,31 +159,48 @@ def test_extract_last_archive_dry_run_calls_borg_with_log_json_flag():
 def test_extract_last_archive_dry_run_calls_borg_with_lock_wait_flags():
     flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
-        ('borg', 'extract', '--dry-run', '--lock-wait', '5', 'repo::archive')
+        ('borg', 'extract', '--dry-run', '--lock-wait', '5', 'repo::archive'),
     )
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_last_archive_dry_run(
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         repository_path='repo',
         lock_wait=5,
     )
 
 
+def test_extract_last_archive_dry_run_calls_borg_with_extra_borg_options():
+    flexmock(module.repo_list).should_receive('resolve_archive_name').and_return('archive')
+    insert_execute_command_mock(
+        ('borg', 'extract', '--dry-run', '--extra', 'value with space', 'repo::archive'),
+    )
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',),
+    )
+
+    module.extract_last_archive_dry_run(
+        config={'extra_borg_options': {'extract': '--extra "value with space"'}},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
+        repository_path='repo',
+    )
+
+
 def test_extract_archive_calls_borg_with_path_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(('borg', 'extract', 'repo::archive', 'path1', 'path2'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -192,7 +210,7 @@ def test_extract_archive_calls_borg_with_path_flags():
         paths=['path1', 'path2'],
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -202,10 +220,10 @@ def test_extract_archive_calls_borg_with_local_path():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -215,7 +233,7 @@ def test_extract_archive_calls_borg_with_local_path():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         local_path='borg1',
     )
 
@@ -224,15 +242,16 @@ def test_extract_archive_calls_borg_with_exit_codes():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     borg_exit_codes = flexmock()
     insert_execute_command_mock(
-        ('borg', 'extract', 'repo::archive'), borg_exit_codes=borg_exit_codes
+        ('borg', 'extract', 'repo::archive'),
+        borg_exit_codes=borg_exit_codes,
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -242,7 +261,7 @@ def test_extract_archive_calls_borg_with_exit_codes():
         paths=None,
         config={'borg_exit_codes': borg_exit_codes},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -252,10 +271,10 @@ def test_extract_archive_calls_borg_with_remote_path_flags():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -265,7 +284,7 @@ def test_extract_archive_calls_borg_with_remote_path_flags():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         remote_path='borg1',
     )
 
@@ -283,10 +302,10 @@ def test_extract_archive_calls_borg_with_numeric_ids_parameter(feature_available
     flexmock(module.feature).should_receive('available').and_return(feature_available)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -296,7 +315,7 @@ def test_extract_archive_calls_borg_with_numeric_ids_parameter(feature_available
         paths=None,
         config={'numeric_ids': True},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -306,10 +325,10 @@ def test_extract_archive_calls_borg_with_umask_flags():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -319,7 +338,7 @@ def test_extract_archive_calls_borg_with_umask_flags():
         paths=None,
         config={'umask': '0770'},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -329,7 +348,7 @@ def test_extract_archive_calls_borg_with_log_json_flags():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
 
     module.extract_archive(
@@ -337,9 +356,9 @@ def test_extract_archive_calls_borg_with_log_json_flags():
         repository='repo',
         archive='archive',
         paths=None,
-        config={},
+        config={'log_json': True},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=True),
+        global_arguments=flexmock(),
     )
 
 
@@ -349,10 +368,10 @@ def test_extract_archive_calls_borg_with_lock_wait_flags():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -362,7 +381,30 @@ def test_extract_archive_calls_borg_with_lock_wait_flags():
         paths=None,
         config={'lock_wait': '5'},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
+    )
+
+
+def test_extract_archive_calls_borg_with_extra_borg_options():
+    flexmock(module.os.path).should_receive('abspath').and_return('repo')
+    insert_execute_command_mock(('borg', 'extract', '--extra', 'value with space', 'repo::archive'))
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',),
+    )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path',
+    ).and_return('repo')
+
+    module.extract_archive(
+        dry_run=False,
+        repository='repo',
+        archive='archive',
+        paths=None,
+        config={'extra_borg_options': {'extract': '--extra "value with space"'}},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(),
     )
 
 
@@ -373,10 +415,10 @@ def test_extract_archive_with_log_info_calls_borg_with_info_parameter():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -386,23 +428,23 @@ def test_extract_archive_with_log_info_calls_borg_with_info_parameter():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
 def test_extract_archive_with_log_debug_calls_borg_with_debug_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(
-        ('borg', 'extract', '--debug', '--list', '--show-rc', 'repo::archive')
+        ('borg', 'extract', '--debug', '--list', '--show-rc', 'repo::archive'),
     )
     insert_logging_mock(logging.DEBUG)
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -412,7 +454,7 @@ def test_extract_archive_with_log_debug_calls_borg_with_debug_flags():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -422,10 +464,10 @@ def test_extract_archive_calls_borg_with_dry_run_parameter():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -435,7 +477,7 @@ def test_extract_archive_calls_borg_with_dry_run_parameter():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -445,10 +487,10 @@ def test_extract_archive_calls_borg_with_destination_path():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -458,7 +500,7 @@ def test_extract_archive_calls_borg_with_destination_path():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         destination_path='/dest',
     )
 
@@ -469,10 +511,10 @@ def test_extract_archive_calls_borg_with_strip_components():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -482,7 +524,7 @@ def test_extract_archive_calls_borg_with_strip_components():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         strip_components=5,
     )
 
@@ -498,15 +540,15 @@ def test_extract_archive_calls_borg_with_strip_components_calculated_from_all():
             'repo::archive',
             'foo/bar/baz.txt',
             'foo/bar.txt',
-        )
+        ),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -516,7 +558,7 @@ def test_extract_archive_calls_borg_with_strip_components_calculated_from_all():
         paths=['foo/bar/baz.txt', 'foo/bar.txt'],
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         strip_components='all',
     )
 
@@ -532,15 +574,15 @@ def test_extract_archive_calls_borg_with_strip_components_calculated_from_all_wi
             'repo::archive',
             '/foo/bar/baz.txt',
             '/foo/bar.txt',
-        )
+        ),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -550,7 +592,7 @@ def test_extract_archive_calls_borg_with_strip_components_calculated_from_all_wi
         paths=['/foo/bar/baz.txt', '/foo/bar.txt'],
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         strip_components='all',
     )
 
@@ -560,10 +602,10 @@ def test_extract_archive_with_strip_components_all_and_no_paths_raises():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
     flexmock(module).should_receive('execute_command').never()
 
@@ -575,12 +617,12 @@ def test_extract_archive_with_strip_components_all_and_no_paths_raises():
             paths=None,
             config={},
             local_borg_version='1.2.3',
-            global_arguments=flexmock(log_json=False),
+            global_arguments=flexmock(),
             strip_components='all',
         )
 
 
-def test_extract_archive_calls_borg_with_progress_parameter():
+def test_extract_archive_calls_borg_with_progress_flag():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -595,10 +637,10 @@ def test_extract_archive_calls_borg_with_progress_parameter():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -606,10 +648,9 @@ def test_extract_archive_calls_borg_with_progress_parameter():
         repository='repo',
         archive='archive',
         paths=None,
-        config={},
+        config={'progress': True},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
-        progress=True,
+        global_arguments=flexmock(),
     )
 
 
@@ -622,10 +663,9 @@ def test_extract_archive_with_progress_and_extract_to_stdout_raises():
             repository='repo',
             archive='archive',
             paths=None,
-            config={},
+            config={'progress': True},
             local_borg_version='1.2.3',
-            global_arguments=flexmock(log_json=False),
-            progress=True,
+            global_arguments=flexmock(),
             extract_to_stdout=True,
         )
 
@@ -647,10 +687,10 @@ def test_extract_archive_calls_borg_with_stdout_parameter_and_returns_process():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('repo::archive',)
+        ('repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     assert (
@@ -661,7 +701,7 @@ def test_extract_archive_calls_borg_with_stdout_parameter_and_returns_process():
             paths=None,
             config={},
             local_borg_version='1.2.3',
-            global_arguments=flexmock(log_json=False),
+            global_arguments=flexmock(),
             extract_to_stdout=True,
         )
         == process
@@ -682,10 +722,10 @@ def test_extract_archive_skips_abspath_for_remote_repository():
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('server:repo::archive',)
+        ('server:repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
+        'normalize_repository_path',
     ).and_return('repo')
 
     module.extract_archive(
@@ -695,22 +735,23 @@ def test_extract_archive_skips_abspath_for_remote_repository():
         paths=None,
         config={},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
 def test_extract_archive_uses_configured_working_directory_in_repo_path_and_destination_path():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(
-        ('borg', 'extract', '/working/dir/repo::archive'), destination_path='/working/dir/dest'
+        ('borg', 'extract', '/working/dir/repo::archive'),
+        destination_path='/working/dir/dest',
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('/working/dir/repo::archive',)
+        ('/working/dir/repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
-    ).with_args('/working/dir/repo').and_return('/working/dir/repo').once()
+        'normalize_repository_path',
+    ).with_args('repo', '/working/dir').and_return('/working/dir/repo').once()
 
     module.extract_archive(
         dry_run=False,
@@ -719,7 +760,7 @@ def test_extract_archive_uses_configured_working_directory_in_repo_path_and_dest
         paths=None,
         config={'working_directory': '/working/dir'},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         destination_path='dest',
     )
 
@@ -729,11 +770,11 @@ def test_extract_archive_uses_configured_working_directory_in_repo_path_when_des
     insert_execute_command_mock(('borg', 'extract', '/working/dir/repo::archive'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
-        ('/working/dir/repo::archive',)
+        ('/working/dir/repo::archive',),
     )
     flexmock(module.borgmatic.config.validate).should_receive(
-        'normalize_repository_path'
-    ).with_args('/working/dir/repo').and_return('/working/dir/repo').once()
+        'normalize_repository_path',
+    ).with_args('repo', '/working/dir').and_return('/working/dir/repo').once()
 
     module.extract_archive(
         dry_run=False,
@@ -742,5 +783,5 @@ def test_extract_archive_uses_configured_working_directory_in_repo_path_when_des
         paths=None,
         config={'working_directory': '/working/dir'},
         local_borg_version='1.2.3',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
