@@ -11,7 +11,9 @@ from ..test_verbosity import insert_logging_mock
 def test_make_info_command_constructs_borg_info_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -20,7 +22,7 @@ def test_make_info_command_constructs_borg_info_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -32,7 +34,9 @@ def test_make_info_command_constructs_borg_info_command():
 def test_make_info_command_with_log_info_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -42,7 +46,7 @@ def test_make_info_command_with_log_info_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -54,7 +58,9 @@ def test_make_info_command_with_log_info_passes_through_to_command():
 def test_make_info_command_with_log_info_and_json_omits_borg_logging_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(('--json',))
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -64,7 +70,7 @@ def test_make_info_command_with_log_info_and_json_omits_borg_logging_flags():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -76,7 +82,9 @@ def test_make_info_command_with_log_info_and_json_omits_borg_logging_flags():
 def test_make_info_command_with_log_debug_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -86,7 +94,7 @@ def test_make_info_command_with_log_debug_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -98,7 +106,9 @@ def test_make_info_command_with_log_debug_passes_through_to_command():
 def test_make_info_command_with_log_debug_and_json_omits_borg_logging_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(('--json',))
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -107,7 +117,7 @@ def test_make_info_command_with_log_debug_and_json_omits_borg_logging_flags():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -119,7 +129,9 @@ def test_make_info_command_with_log_debug_and_json_omits_borg_logging_flags():
 def test_make_info_command_with_json_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(('--json',))
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -128,7 +140,7 @@ def test_make_info_command_with_json_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -140,7 +152,9 @@ def test_make_info_command_with_json_passes_through_to_command():
 def test_make_info_command_with_archive_uses_match_archives_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'archive', None, '2.3.4'
+        'archive',
+        None,
+        '2.3.4',
     ).and_return(('--match-archives', 'archive'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -149,7 +163,7 @@ def test_make_info_command_with_archive_uses_match_archives_flags():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive='archive', json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -161,7 +175,9 @@ def test_make_info_command_with_archive_uses_match_archives_flags():
 def test_make_info_command_with_local_path_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -170,22 +186,25 @@ def test_make_info_command_with_local_path_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg1',
         remote_path=None,
     )
 
-    command == ('borg1', 'info', '--repo', 'repo')
+    assert command == ('borg1', 'info', '--repo', 'repo')
 
 
 def test_make_info_command_with_remote_path_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args(
-        'remote-path', 'borg1'
+        'remote-path',
+        'borg1',
     ).and_return(('--remote-path', 'borg1'))
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -194,7 +213,7 @@ def test_make_info_command_with_remote_path_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path='borg1',
@@ -205,10 +224,12 @@ def test_make_info_command_with_remote_path_passes_through_to_command():
 
 def test_make_info_command_with_umask_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -217,7 +238,7 @@ def test_make_info_command_with_umask_passes_through_to_command():
         repository_path='repo',
         config={'umask': '077'},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -229,19 +250,21 @@ def test_make_info_command_with_umask_passes_through_to_command():
 def test_make_info_command_with_log_json_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
-        ('--log-json',)
+        ('--log-json',),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
 
     command = module.make_info_command(
         repository_path='repo',
-        config={},
+        config={'log_json': True},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=True),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -253,10 +276,12 @@ def test_make_info_command_with_log_json_passes_through_to_command():
 def test_make_info_command_with_lock_wait_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('lock-wait', 5).and_return(
-        ('--lock-wait', '5')
+        ('--lock-wait', '5'),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -266,7 +291,7 @@ def test_make_info_command_with_lock_wait_passes_through_to_command():
         repository_path='repo',
         config=config,
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -275,13 +300,40 @@ def test_make_info_command_with_lock_wait_passes_through_to_command():
     assert command == ('borg', 'info', '--lock-wait', '5', '--repo', 'repo')
 
 
+def test_make_info_command_with_extra_borg_options_passes_through_to_command():
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None,
+        None,
+        '2.3.4',
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    config = {'extra_borg_options': {'info': '--extra "value with space"'}}
+
+    command = module.make_info_command(
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(),
+        info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
+        local_path='borg',
+        remote_path=None,
+    )
+
+    assert command == ('borg', 'info', '--extra', 'value with space', '--repo', 'repo')
+
+
 def test_make_info_command_transforms_prefix_into_match_archives_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args(
-        'match-archives', 'sh:foo*'
+        'match-archives',
+        'sh:foo*',
     ).and_return(('--match-archives', 'sh:foo*'))
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -290,7 +342,7 @@ def test_make_info_command_transforms_prefix_into_match_archives_flags():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix='foo'),
         local_path='borg',
         remote_path=None,
@@ -302,19 +354,22 @@ def test_make_info_command_transforms_prefix_into_match_archives_flags():
 def test_make_info_command_prefers_prefix_over_archive_name_format():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args(
-        'match-archives', 'sh:foo*'
+        'match-archives',
+        'sh:foo*',
     ).and_return(('--match-archives', 'sh:foo*'))
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
 
     command = module.make_info_command(
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix='foo'),
         local_path='borg',
         remote_path=None,
@@ -326,16 +381,18 @@ def test_make_info_command_prefers_prefix_over_archive_name_format():
 def test_make_info_command_transforms_archive_name_format_into_match_archives_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, 'bar-{now}', '2.3.4'  # noqa: FS003
+        None,
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'sh:bar-*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
 
     command = module.make_info_command(
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -347,7 +404,9 @@ def test_make_info_command_transforms_archive_name_format_into_match_archives_fl
 def test_make_info_command_with_match_archives_option_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'sh:foo-*', 'bar-{now}', '2.3.4'  # noqa: FS003
+        'sh:foo-*',
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'sh:foo-*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -356,11 +415,11 @@ def test_make_info_command_with_match_archives_option_passes_through_to_command(
     command = module.make_info_command(
         repository_path='repo',
         config={
-            'archive_name_format': 'bar-{now}',  # noqa: FS003
+            'archive_name_format': 'bar-{now}',
             'match_archives': 'sh:foo-*',
         },
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg',
         remote_path=None,
@@ -372,7 +431,9 @@ def test_make_info_command_with_match_archives_option_passes_through_to_command(
 def test_make_info_command_with_match_archives_flag_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'sh:foo-*', 'bar-{now}', '2.3.4'  # noqa: FS003
+        'sh:foo-*',
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'sh:foo-*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -380,9 +441,9 @@ def test_make_info_command_with_match_archives_flag_passes_through_to_command():
 
     command = module.make_info_command(
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}', 'match_archives': 'sh:foo-*'},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives='sh:foo-*'),
         local_path='borg',
         remote_path=None,
@@ -396,10 +457,12 @@ def test_make_info_command_passes_arguments_through_to_command(argument_name):
     flag_name = f"--{argument_name.replace('_', ' ')}"
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
-        (flag_name, 'value')
+        (flag_name, 'value'),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
@@ -408,9 +471,13 @@ def test_make_info_command_passes_arguments_through_to_command(argument_name):
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(
-            archive=None, json=False, prefix=None, match_archives=None, **{argument_name: 'value'}
+            archive=None,
+            json=False,
+            prefix=None,
+            match_archives=None,
+            **{argument_name: 'value'},
         ),
         local_path='borg',
         remote_path=None,
@@ -422,10 +489,12 @@ def test_make_info_command_passes_arguments_through_to_command(argument_name):
 def test_make_info_command_with_date_based_matching_passes_through_to_command():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, None, '2.3.4'
+        None,
+        None,
+        '2.3.4',
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
-        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w')
+        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w'),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     info_arguments = flexmock(
@@ -443,7 +512,7 @@ def test_make_info_command_with_date_based_matching_passes_through_to_command():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=info_arguments,
         local_path='borg',
         remote_path=None,
@@ -478,7 +547,7 @@ def test_display_archives_info_calls_two_commands():
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -498,7 +567,7 @@ def test_display_archives_info_with_json_calls_json_command_only():
             repository_path='repo',
             config={},
             local_borg_version='2.3.4',
-            global_arguments=flexmock(log_json=False),
+            global_arguments=flexmock(),
             info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
         )
         == json_output
@@ -533,6 +602,6 @@ def test_display_archives_info_calls_borg_with_working_directory():
         repository_path='repo',
         config={'working_directory': '/working/dir'},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
