@@ -14,20 +14,24 @@ REPO_CREATE_COMMAND = ('borg', 'repo-create', '--encryption', 'repokey')
 
 def insert_repo_info_command_found_mock():
     flexmock(module.repo_info).should_receive('display_repository_info').and_return(
-        '{"encryption": {"mode": "repokey"}}'
+        '{"encryption": {"mode": "repokey"}}',
     )
 
 
 def insert_repo_info_command_not_found_mock():
     flexmock(module.repo_info).should_receive('display_repository_info').and_raise(
         subprocess.CalledProcessError(
-            sorted(module.REPO_INFO_REPOSITORY_NOT_FOUND_EXIT_CODES)[0], []
-        )
+            sorted(module.REPO_INFO_REPOSITORY_NOT_FOUND_EXIT_CODES)[0],
+            [],
+        ),
     )
 
 
 def insert_repo_create_command_mock(
-    repo_create_command, working_directory=None, borg_exit_codes=None, **kwargs
+    repo_create_command,
+    working_directory=None,
+    borg_exit_codes=None,
+    **kwargs,
 ):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
@@ -45,13 +49,13 @@ def insert_repo_create_command_mock(
 
 def test_create_repository_calls_borg_with_flags():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -72,7 +76,7 @@ def test_create_repository_with_dry_run_skips_borg_call():
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -92,12 +96,12 @@ def test_create_repository_raises_for_borg_repo_create_error():
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').and_raise(
-        module.subprocess.CalledProcessError(2, 'borg repo_create')
+        module.subprocess.CalledProcessError(2, 'borg repo_create'),
     )
 
     with pytest.raises(subprocess.CalledProcessError):
@@ -118,7 +122,7 @@ def test_create_repository_skips_creation_when_repository_already_exists():
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -138,7 +142,7 @@ def test_create_repository_errors_when_repository_with_differing_encryption_mode
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     with pytest.raises(ValueError):
@@ -154,7 +158,7 @@ def test_create_repository_errors_when_repository_with_differing_encryption_mode
 
 def test_create_repository_raises_for_unknown_repo_info_command_error():
     flexmock(module.repo_info).should_receive('display_repository_info').and_raise(
-        subprocess.CalledProcessError(REPO_INFO_SOME_UNKNOWN_EXIT_CODE, [])
+        subprocess.CalledProcessError(REPO_INFO_SOME_UNKNOWN_EXIT_CODE, []),
     )
 
     with pytest.raises(subprocess.CalledProcessError):
@@ -171,14 +175,14 @@ def test_create_repository_raises_for_unknown_repo_info_command_error():
 def test_create_repository_with_source_repository_calls_borg_with_other_repo_flag():
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        REPO_CREATE_COMMAND + ('--other-repo', 'other.borg', '--repo', 'repo')
+        (*REPO_CREATE_COMMAND, '--other-repo', 'other.borg', '--repo', 'repo'),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -194,13 +198,13 @@ def test_create_repository_with_source_repository_calls_borg_with_other_repo_fla
 
 def test_create_repository_with_copy_crypt_key_calls_borg_with_copy_crypt_key_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--copy-crypt-key', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--copy-crypt-key', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -216,13 +220,13 @@ def test_create_repository_with_copy_crypt_key_calls_borg_with_copy_crypt_key_fl
 
 def test_create_repository_with_append_only_calls_borg_with_append_only_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--append-only', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--append-only', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -238,13 +242,13 @@ def test_create_repository_with_append_only_calls_borg_with_append_only_flag():
 
 def test_create_repository_with_append_only_config_calls_borg_with_append_only_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--append-only', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--append-only', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -261,14 +265,14 @@ def test_create_repository_with_append_only_config_calls_borg_with_append_only_f
 def test_create_repository_with_storage_quota_calls_borg_with_storage_quota_flag():
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        REPO_CREATE_COMMAND + ('--storage-quota', '5G', '--repo', 'repo')
+        (*REPO_CREATE_COMMAND, '--storage-quota', '5G', '--repo', 'repo'),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -284,13 +288,13 @@ def test_create_repository_with_storage_quota_calls_borg_with_storage_quota_flag
 
 def test_create_repository_with_make_parent_dirs_calls_borg_with_make_parent_dirs_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--make-parent-dirs', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--make-parent-dirs', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -306,14 +310,14 @@ def test_create_repository_with_make_parent_dirs_calls_borg_with_make_parent_dir
 
 def test_create_repository_with_log_info_calls_borg_with_info_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--info', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--info', '--repo', 'repo'))
     insert_logging_mock(logging.INFO)
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -328,14 +332,14 @@ def test_create_repository_with_log_info_calls_borg_with_info_flag():
 
 def test_create_repository_with_log_debug_calls_borg_with_debug_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--debug', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--debug', '--repo', 'repo'))
     insert_logging_mock(logging.DEBUG)
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -350,13 +354,13 @@ def test_create_repository_with_log_debug_calls_borg_with_debug_flag():
 
 def test_create_repository_with_log_json_calls_borg_with_log_json_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--log-json', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--log-json', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -371,13 +375,13 @@ def test_create_repository_with_log_json_calls_borg_with_log_json_flag():
 
 def test_create_repository_with_lock_wait_calls_borg_with_lock_wait_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--lock-wait', '5', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--lock-wait', '5', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -392,13 +396,13 @@ def test_create_repository_with_lock_wait_calls_borg_with_lock_wait_flag():
 
 def test_create_repository_with_local_path_calls_borg_via_local_path():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(('borg1',) + REPO_CREATE_COMMAND[1:] + ('--repo', 'repo'))
+    insert_repo_create_command_mock(('borg1', *REPO_CREATE_COMMAND[1:], '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -416,14 +420,15 @@ def test_create_repository_with_exit_codes_calls_borg_using_them():
     borg_exit_codes = flexmock()
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        ('borg',) + REPO_CREATE_COMMAND[1:] + ('--repo', 'repo'), borg_exit_codes=borg_exit_codes
+        ('borg', *REPO_CREATE_COMMAND[1:], '--repo', 'repo'),
+        borg_exit_codes=borg_exit_codes,
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -439,14 +444,14 @@ def test_create_repository_with_exit_codes_calls_borg_using_them():
 def test_create_repository_with_remote_path_calls_borg_with_remote_path_flag():
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        REPO_CREATE_COMMAND + ('--remote-path', 'borg1', '--repo', 'repo')
+        (*REPO_CREATE_COMMAND, '--remote-path', 'borg1', '--repo', 'repo'),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -462,13 +467,13 @@ def test_create_repository_with_remote_path_calls_borg_with_remote_path_flag():
 
 def test_create_repository_with_umask_calls_borg_with_umask_flag():
     insert_repo_info_command_not_found_mock()
-    insert_repo_create_command_mock(REPO_CREATE_COMMAND + ('--umask', '077', '--repo', 'repo'))
+    insert_repo_create_command_mock((*REPO_CREATE_COMMAND, '--umask', '077', '--repo', 'repo'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -481,17 +486,17 @@ def test_create_repository_with_umask_calls_borg_with_umask_flag():
     )
 
 
-def test_create_repository_with_extra_borg_options_calls_borg_with_extra_options():
+def test_create_repository_calls_borg_with_extra_borg_options():
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        REPO_CREATE_COMMAND + ('--extra', '--options', 'value with space', '--repo', 'repo')
+        (*REPO_CREATE_COMMAND, '--extra', '--options', 'value with space', '--repo', 'repo'),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
 
     module.create_repository(
@@ -504,17 +509,42 @@ def test_create_repository_with_extra_borg_options_calls_borg_with_extra_options
     )
 
 
-def test_create_repository_calls_borg_with_working_directory():
+def test_create_repository_calls_borg_with_extra_borg_options_from_deprecated_init_option():
+    flexmock(module.logger).should_receive('warning').once()
     insert_repo_info_command_not_found_mock()
     insert_repo_create_command_mock(
-        REPO_CREATE_COMMAND + ('--repo', 'repo'), working_directory='/working/dir'
+        (*REPO_CREATE_COMMAND, '--extra', '--options', 'value with space', '--repo', 'repo'),
     )
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
+    )
+
+    module.create_repository(
+        dry_run=False,
+        repository_path='repo',
+        config={'extra_borg_options': {'init': '--extra --options "value with space"'}},
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(),
+        encryption_mode='repokey',
+    )
+
+
+def test_create_repository_calls_borg_with_working_directory():
+    insert_repo_info_command_not_found_mock()
+    insert_repo_create_command_mock(
+        (*REPO_CREATE_COMMAND, '--repo', 'repo'),
+        working_directory='/working/dir',
+    )
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(
+        (
+            '--repo',
+            'repo',
+        ),
     )
 
     module.create_repository(
