@@ -12,15 +12,15 @@ def test_make_repo_delete_command_with_feature_available_runs_borg_repo_delete()
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -33,15 +33,15 @@ def test_make_repo_delete_command_without_feature_available_runs_borg_delete():
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -55,15 +55,15 @@ def test_make_repo_delete_command_includes_log_info():
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -77,15 +77,15 @@ def test_make_repo_delete_command_includes_log_debug():
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -97,19 +97,20 @@ def test_make_repo_delete_command_includes_dry_run():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'dry-run', True
+        'dry-run',
+        True,
     ).and_return(('--dry-run',))
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=True, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=True),
         local_path='borg',
         remote_path=None,
     )
@@ -121,19 +122,20 @@ def test_make_repo_delete_command_includes_remote_path():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'remote-path', 'borg1'
+        'remote-path',
+        'borg1',
     ).and_return(('--remote-path', 'borg1'))
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path='borg1',
     )
@@ -144,19 +146,19 @@ def test_make_repo_delete_command_includes_remote_path():
 def test_make_repo_delete_command_includes_umask():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={'umask': '077'},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -168,19 +170,20 @@ def test_make_repo_delete_command_includes_log_json():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'log-json', True
+        'log-json',
+        True,
     ).and_return(('--log-json',))
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
-        config={},
+        config={'log_json': True},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=True),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -192,19 +195,20 @@ def test_make_repo_delete_command_includes_lock_wait():
     flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'lock-wait', 5
+        'lock-wait',
+        5,
     ).and_return(('--lock-wait', '5'))
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={'lock_wait': 5},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -212,23 +216,66 @@ def test_make_repo_delete_command_includes_lock_wait():
     assert command == ('borg', 'repo-delete', '--lock-wait', '5', 'repo')
 
 
-def test_make_repo_delete_command_includes_list():
-    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
+def test_make_repo_delete_command_without_feature_available_includes_delete_extra_borg_options():
+    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(False)
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
-    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
-        'list', True
-    ).and_return(('--list',))
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
-        config={},
+        config={'extra_borg_options': {'delete': '--extra "value with space"'}},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=True, force=0),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
+        local_path='borg',
+        remote_path=None,
+    )
+
+    assert command == ('borg', 'delete', '--extra', 'value with space', 'repo')
+
+
+def test_make_repo_delete_command_with_feature_available_includes_delete_extra_borg_options():
+    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
+        ('repo',),
+    )
+
+    command = module.make_repo_delete_command(
+        repository={'path': 'repo'},
+        config={'extra_borg_options': {'repo_delete': '--extra "value with space"'}},
+        local_borg_version='1.2.3',
+        repo_delete_arguments=flexmock(list_details=False, force=0),
+        global_arguments=flexmock(dry_run=False),
+        local_path='borg',
+        remote_path=None,
+    )
+
+    assert command == ('borg', 'repo-delete', '--extra', 'value with space', 'repo')
+
+
+def test_make_repo_delete_command_includes_list():
+    flexmock(module.borgmatic.borg.feature).should_receive('available').and_return(True)
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags').with_args(
+        'list',
+        True,
+    ).and_return(('--list',))
+    flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
+        ('repo',),
+    )
+
+    command = module.make_repo_delete_command(
+        repository={'path': 'repo'},
+        config={'list_details': True},
+        local_borg_version='1.2.3',
+        repo_delete_arguments=flexmock(list_details=True, force=0),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -241,15 +288,15 @@ def test_make_repo_delete_command_includes_force():
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=1),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=1),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -262,15 +309,15 @@ def test_make_repo_delete_command_includes_force_twice():
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.borgmatic.borg.flags).should_receive('make_repository_flags').and_return(
-        ('repo',)
+        ('repo',),
     )
 
     command = module.make_repo_delete_command(
         repository={'path': 'repo'},
         config={},
         local_borg_version='1.2.3',
-        repo_delete_arguments=flexmock(list_archives=False, force=2),
-        global_arguments=flexmock(dry_run=False, log_json=False),
+        repo_delete_arguments=flexmock(list_details=False, force=2),
+        global_arguments=flexmock(dry_run=False),
         local_path='borg',
         remote_path=None,
     )
@@ -283,7 +330,7 @@ def test_delete_repository_with_defaults_does_not_capture_output():
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive('execute_command').with_args(
@@ -312,7 +359,7 @@ def test_delete_repository_with_force_captures_output():
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive('execute_command').with_args(
@@ -341,7 +388,7 @@ def test_delete_repository_with_cache_only_captures_output():
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module.borgmatic.execute).should_receive('execute_command').with_args(
@@ -370,7 +417,7 @@ def test_delete_repository_calls_borg_with_working_directory():
     command = flexmock()
     flexmock(module).should_receive('make_repo_delete_command').and_return(command)
     flexmock(module.borgmatic.borg.environment).should_receive('make_environment').and_return(
-        flexmock()
+        flexmock(),
     )
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
         '/working/dir',
