@@ -12,13 +12,13 @@ def test_display_repository_info_calls_borg_with_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -44,7 +44,7 @@ def test_display_repository_info_calls_borg_with_flags():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -53,7 +53,7 @@ def test_display_repository_info_without_borg_features_calls_borg_with_info_sub_
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.environment).should_receive('make_environment')
@@ -80,7 +80,7 @@ def test_display_repository_info_without_borg_features_calls_borg_with_info_sub_
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -89,13 +89,13 @@ def test_display_repository_info_with_log_info_calls_borg_with_info_flag():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -121,7 +121,7 @@ def test_display_repository_info_with_log_info_calls_borg_with_info_flag():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -130,13 +130,13 @@ def test_display_repository_info_with_log_info_and_json_suppresses_most_borg_out
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -155,7 +155,7 @@ def test_display_repository_info_with_log_info_and_json_suppresses_most_borg_out
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=True),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
     assert json_output == '[]'
@@ -166,13 +166,13 @@ def test_display_repository_info_with_log_debug_calls_borg_with_debug_flag():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -199,7 +199,7 @@ def test_display_repository_info_with_log_debug_calls_borg_with_debug_flag():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -208,13 +208,13 @@ def test_display_repository_info_with_log_debug_and_json_suppresses_most_borg_ou
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -233,7 +233,7 @@ def test_display_repository_info_with_log_debug_and_json_suppresses_most_borg_ou
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=True),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
     assert json_output == '[]'
@@ -244,13 +244,13 @@ def test_display_repository_info_with_json_calls_borg_with_json_flag():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -268,7 +268,7 @@ def test_display_repository_info_with_json_calls_borg_with_json_flag():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=True),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
     assert json_output == '[]'
@@ -279,13 +279,13 @@ def test_display_repository_info_with_local_path_calls_borg_via_local_path():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -311,7 +311,7 @@ def test_display_repository_info_with_local_path_calls_borg_via_local_path():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         local_path='borg1',
     )
 
@@ -321,13 +321,13 @@ def test_display_repository_info_with_exit_codes_calls_borg_using_them():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -354,7 +354,7 @@ def test_display_repository_info_with_exit_codes_calls_borg_using_them():
         config={'borg_exit_codes': borg_exit_codes},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -363,13 +363,13 @@ def test_display_repository_info_with_remote_path_calls_borg_with_remote_path_fl
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -395,7 +395,7 @@ def test_display_repository_info_with_remote_path_calls_borg_with_remote_path_fl
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         remote_path='borg1',
     )
 
@@ -405,13 +405,13 @@ def test_display_repository_info_with_umask_calls_borg_with_umask_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -437,7 +437,7 @@ def test_display_repository_info_with_umask_calls_borg_with_umask_flags():
         config={'umask': '077'},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         remote_path=None,
     )
 
@@ -447,16 +447,16 @@ def test_display_repository_info_with_log_json_calls_borg_with_log_json_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
-        ('--log-json',)
+        ('--log-json',),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -479,10 +479,10 @@ def test_display_repository_info_with_log_json_calls_borg_with_log_json_flags():
 
     module.display_repository_info(
         repository_path='repo',
-        config={},
+        config={'log_json': True},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=True),
+        global_arguments=flexmock(),
     )
 
 
@@ -492,13 +492,13 @@ def test_display_repository_info_with_lock_wait_calls_borg_with_lock_wait_flags(
     config = {'lock_wait': 5}
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', str(value)) if value else ()
+        lambda name, value: (f'--{name}', str(value)) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -524,7 +524,91 @@ def test_display_repository_info_with_lock_wait_calls_borg_with_lock_wait_flags(
         config=config,
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
+    )
+
+
+def test_display_repository_info_without_feature_available_calls_borg_with_info_extra_borg_options():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    config = {'extra_borg_options': {'info': '--extra "value with space"'}}
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_flags').replace_with(
+        lambda name, value: (f'--{name}', str(value)) if value else (),
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(
+        (
+            '--repo',
+            'repo',
+        ),
+    )
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        ('borg', 'info', '--extra', 'value with space', '--json', '--repo', 'repo'),
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    ).and_return('[]')
+    flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags')
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'info', '--extra', 'value with space', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    )
+
+    module.display_repository_info(
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        repo_info_arguments=flexmock(json=False),
+        global_arguments=flexmock(),
+    )
+
+
+def test_display_repository_info_with_feature_available_calls_borg_with_repo_info_extra_borg_options():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    config = {'extra_borg_options': {'repo_info': '--extra "value with space"'}}
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_flags').replace_with(
+        lambda name, value: (f'--{name}', str(value)) if value else (),
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(
+        (
+            '--repo',
+            'repo',
+        ),
+    )
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        ('borg', 'repo-info', '--extra', 'value with space', '--json', '--repo', 'repo'),
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    ).and_return('[]')
+    flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags')
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'repo-info', '--extra', 'value with space', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    )
+
+    module.display_repository_info(
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        repo_info_arguments=flexmock(json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -533,13 +617,13 @@ def test_display_repository_info_calls_borg_with_working_directory():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(
         (
             '--repo',
             'repo',
-        )
+        ),
     )
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
@@ -567,5 +651,5 @@ def test_display_repository_info_calls_borg_with_working_directory():
         config={},
         local_borg_version='2.3.4',
         repo_info_arguments=flexmock(json=False),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
