@@ -33,9 +33,12 @@ def test_transfer_archives_calls_borg_with_flags():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -44,7 +47,7 @@ def test_transfer_archives_with_dry_run_calls_borg_with_dry_run_flag():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('dry-run', True).and_return(
-        ('--dry-run',)
+        ('--dry-run',),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -67,9 +70,12 @@ def test_transfer_archives_with_dry_run_calls_borg_with_dry_run_flag():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -98,9 +104,12 @@ def test_transfer_archives_with_log_info_calls_borg_with_info_flag():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -130,9 +139,12 @@ def test_transfer_archives_with_log_debug_calls_borg_with_debug_flag():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -141,7 +153,9 @@ def test_transfer_archives_with_archive_calls_borg_with_match_archives_flag():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'archive', 'bar-{now}', '2.3.4'  # noqa: FS003
+        'archive',
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'archive'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -160,12 +174,15 @@ def test_transfer_archives_with_archive_calls_borg_with_match_archives_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive='archive', progress=None, match_archives=None, source_repository=None
+            archive='archive',
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -174,7 +191,9 @@ def test_transfer_archives_with_match_archives_calls_borg_with_match_archives_fl
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'sh:foo*', 'bar-{now}', '2.3.4'  # noqa: FS003
+        'sh:foo*',
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'sh:foo*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -193,12 +212,15 @@ def test_transfer_archives_with_match_archives_calls_borg_with_match_archives_fl
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}', 'match_archives': 'sh:foo*'},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives='sh:foo*', source_repository=None
+            archive=None,
+            progress=None,
+            match_archives='sh:foo*',
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -207,7 +229,9 @@ def test_transfer_archives_with_archive_name_format_calls_borg_with_match_archiv
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None, 'bar-{now}', '2.3.4'  # noqa: FS003
+        None,
+        'bar-{now}',
+        '2.3.4',
     ).and_return(('--match-archives', 'sh:bar-*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
@@ -226,12 +250,15 @@ def test_transfer_archives_with_archive_name_format_calls_borg_with_match_archiv
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -260,9 +287,12 @@ def test_transfer_archives_with_local_path_calls_borg_via_local_path():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         local_path='borg2',
     )
 
@@ -293,9 +323,12 @@ def test_transfer_archives_with_exit_codes_calls_borg_using_them():
         config={'borg_exit_codes': borg_exit_codes},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -304,7 +337,8 @@ def test_transfer_archives_with_remote_path_calls_borg_with_remote_path_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args(
-        'remote-path', 'borg2'
+        'remote-path',
+        'borg2',
     ).and_return(('--remote-path', 'borg2'))
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -327,9 +361,12 @@ def test_transfer_archives_with_remote_path_calls_borg_with_remote_path_flags():
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         remote_path='borg2',
     )
 
@@ -338,7 +375,7 @@ def test_transfer_archives_with_umask_calls_borg_with_umask_flags():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').replace_with(
-        lambda name, value: (f'--{name}', value) if value else ()
+        lambda name, value: (f'--{name}', value) if value else (),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -361,9 +398,12 @@ def test_transfer_archives_with_umask_calls_borg_with_umask_flags():
         config={'umask': '077'},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -372,7 +412,7 @@ def test_transfer_archives_with_log_json_calls_borg_with_log_json_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
-        ('--log-json',)
+        ('--log-json',),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -392,12 +432,15 @@ def test_transfer_archives_with_log_json_calls_borg_with_log_json_flags():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        config={},
+        config={'log_json': True},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=True),
+        global_arguments=flexmock(),
     )
 
 
@@ -406,7 +449,7 @@ def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('lock-wait', 5).and_return(
-        ('--lock-wait', '5')
+        ('--lock-wait', '5'),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -430,18 +473,59 @@ def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
         config=config,
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
-def test_transfer_archives_with_progress_calls_borg_with_progress_flag():
+def test_transfer_archives_calls_borg_with_extra_borg_options():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
-    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(('--progress',))
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    config = {'extra_borg_options': {'transfer': '--extra "value with space"'}}
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'transfer', '--extra', 'value with space', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        output_file=None,
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    )
+
+    module.transfer_archives(
+        dry_run=False,
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        transfer_arguments=flexmock(
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
+        ),
+        global_arguments=flexmock(),
+    )
+
+
+def test_transfer_archives_with_progress_calls_borg_with_progress_flags():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args('progress', True).and_return(
+        ('--progress',),
+    )
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
@@ -458,12 +542,15 @@ def test_transfer_archives_with_progress_calls_borg_with_progress_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        config={},
+        config={'progress': True},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=True, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -475,7 +562,7 @@ def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
-        (flag_name, 'value')
+        (flag_name, 'value'),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
@@ -502,7 +589,7 @@ def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
             source_repository=None,
             **{argument_name: 'value'},
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -510,7 +597,7 @@ def test_transfer_archives_with_source_repository_calls_borg_with_other_repo_fla
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags').with_args('other-repo', 'other').and_return(
-        ('--other-repo', 'other')
+        ('--other-repo', 'other'),
     )
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
@@ -533,9 +620,12 @@ def test_transfer_archives_with_source_repository_calls_borg_with_other_repo_fla
         config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository='other'
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository='other',
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
 
 
@@ -544,7 +634,7 @@ def test_transfer_archives_with_date_based_matching_calls_borg_with_date_based_f
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
-        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w')
+        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w'),
     )
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
@@ -577,7 +667,7 @@ def test_transfer_archives_with_date_based_matching_calls_borg_with_date_based_f
         repository_path='repo',
         config={},
         local_borg_version='2.3.4',
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
         transfer_arguments=flexmock(
             archive=None,
             progress=None,
@@ -617,7 +707,10 @@ def test_transfer_archives_calls_borg_with_working_directory():
         config={'working_directory': '/working/dir'},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
-            archive=None, progress=None, match_archives=None, source_repository=None
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
         ),
-        global_arguments=flexmock(log_json=False),
+        global_arguments=flexmock(),
     )
