@@ -44,19 +44,23 @@ def test_interactive_console_true_when_isatty_and_TERM_is_not_dumb(capsys):
         assert module.interactive_console() is True
 
 
-def test_should_do_markup_respects_no_color_value():
-    flexmock(module.os.environ).should_receive('get').and_return(None)
+def test_should_do_markup_respects_json_enabled_value():
+    flexmock(module.os.environ).should_receive('get').never()
     flexmock(module).should_receive('interactive_console').never()
-    assert module.should_do_markup(no_color=True, configs={}) is False
+    assert module.should_do_markup(configs={}, json_enabled=True) is False
 
 
 def test_should_do_markup_respects_config_value():
     flexmock(module.os.environ).should_receive('get').and_return(None)
     flexmock(module).should_receive('interactive_console').never()
-    assert module.should_do_markup(no_color=False, configs={'foo.yaml': {'color': False}}) is False
+    assert (
+        module.should_do_markup(configs={'foo.yaml': {'color': False}}, json_enabled=False) is False
+    )
 
     flexmock(module).should_receive('interactive_console').and_return(True).once()
-    assert module.should_do_markup(no_color=False, configs={'foo.yaml': {'color': True}}) is True
+    assert (
+        module.should_do_markup(configs={'foo.yaml': {'color': True}}, json_enabled=False) is True
+    )
 
 
 def test_should_do_markup_prefers_any_false_config_value():
@@ -65,11 +69,11 @@ def test_should_do_markup_prefers_any_false_config_value():
 
     assert (
         module.should_do_markup(
-            no_color=False,
             configs={
                 'foo.yaml': {'color': True},
                 'bar.yaml': {'color': False},
             },
+            json_enabled=False,
         )
         is False
     )
@@ -77,20 +81,22 @@ def test_should_do_markup_prefers_any_false_config_value():
 
 def test_should_do_markup_respects_PY_COLORS_environment_variable():
     flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
-        'True'
+        'True',
     )
     flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(None)
 
     flexmock(module).should_receive('to_bool').and_return(True)
 
-    assert module.should_do_markup(no_color=False, configs={}) is True
+    assert module.should_do_markup(configs={}, json_enabled=False) is True
 
 
-def test_should_do_markup_prefers_no_color_value_to_config_value():
+def test_should_do_markup_prefers_json_enabled_value_to_config_value():
     flexmock(module.os.environ).should_receive('get').and_return(None)
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=True, configs={'foo.yaml': {'color': True}}) is False
+    assert (
+        module.should_do_markup(configs={'foo.yaml': {'color': True}}, json_enabled=True) is False
+    )
 
 
 def test_should_do_markup_prefers_config_value_to_environment_variables():
@@ -98,7 +104,9 @@ def test_should_do_markup_prefers_config_value_to_environment_variables():
     flexmock(module).should_receive('to_bool').and_return(True)
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=False, configs={'foo.yaml': {'color': False}}) is False
+    assert (
+        module.should_do_markup(configs={'foo.yaml': {'color': False}}, json_enabled=False) is False
+    )
 
 
 def test_should_do_markup_prefers_no_color_value_to_environment_variables():
@@ -106,25 +114,25 @@ def test_should_do_markup_prefers_no_color_value_to_environment_variables():
     flexmock(module).should_receive('to_bool').and_return(True)
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=True, configs={}) is False
+    assert module.should_do_markup(configs={}, json_enabled=False) is False
 
 
 def test_should_do_markup_respects_interactive_console_value():
     flexmock(module.os.environ).should_receive('get').and_return(None)
     flexmock(module).should_receive('interactive_console').and_return(True)
 
-    assert module.should_do_markup(no_color=False, configs={}) is True
+    assert module.should_do_markup(configs={}, json_enabled=False) is True
 
 
 def test_should_do_markup_prefers_PY_COLORS_to_interactive_console_value():
     flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
-        'True'
+        'True',
     )
     flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(None)
     flexmock(module).should_receive('to_bool').and_return(True)
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=False, configs={}) is True
+    assert module.should_do_markup(configs={}, json_enabled=False) is True
 
 
 def test_should_do_markup_prefers_NO_COLOR_to_interactive_console_value():
@@ -132,7 +140,7 @@ def test_should_do_markup_prefers_NO_COLOR_to_interactive_console_value():
     flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return('True')
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=False, configs={}) is False
+    assert module.should_do_markup(configs={}, json_enabled=False) is False
 
 
 def test_should_do_markup_respects_NO_COLOR_environment_variable():
@@ -140,7 +148,7 @@ def test_should_do_markup_respects_NO_COLOR_environment_variable():
     flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(None)
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=False, configs={}) is False
+    assert module.should_do_markup(configs={}, json_enabled=False) is False
 
 
 def test_should_do_markup_ignores_empty_NO_COLOR_environment_variable():
@@ -148,19 +156,19 @@ def test_should_do_markup_ignores_empty_NO_COLOR_environment_variable():
     flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(None)
     flexmock(module).should_receive('interactive_console').and_return(True)
 
-    assert module.should_do_markup(no_color=False, configs={}) is True
+    assert module.should_do_markup(configs={}, json_enabled=False) is True
 
 
 def test_should_do_markup_prefers_NO_COLOR_to_PY_COLORS():
     flexmock(module.os.environ).should_receive('get').with_args('PY_COLORS', None).and_return(
-        'True'
+        'True',
     )
     flexmock(module.os.environ).should_receive('get').with_args('NO_COLOR', None).and_return(
-        'SomeValue'
+        'SomeValue',
     )
     flexmock(module).should_receive('interactive_console').never()
 
-    assert module.should_do_markup(no_color=False, configs={}) is False
+    assert module.should_do_markup(configs={}, json_enabled=False) is False
 
 
 def test_multi_stream_handler_logs_to_handler_for_log_level():
@@ -169,7 +177,7 @@ def test_multi_stream_handler_logs_to_handler_for_log_level():
     info_handler = flexmock()
 
     multi_handler = module.Multi_stream_handler(
-        {module.logging.ERROR: error_handler, module.logging.INFO: info_handler}
+        {module.logging.ERROR: error_handler, module.logging.INFO: info_handler},
     )
     multi_handler.emit(flexmock(levelno=module.logging.ERROR))
 
@@ -236,7 +244,7 @@ def test_get_log_prefix_gets_prefix_from_first_handler_formatter_with_prefix():
                 flexmock(formatter=flexmock(prefix='myprefix')),
             ],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     assert module.get_log_prefix() == 'myprefix'
@@ -247,7 +255,7 @@ def test_get_log_prefix_with_no_handlers_does_not_raise():
         flexmock(
             handlers=[],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     assert module.get_log_prefix() is None
@@ -261,7 +269,7 @@ def test_get_log_prefix_with_no_formatters_does_not_raise():
                 flexmock(formatter=None),
             ],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     assert module.get_log_prefix() is None
@@ -276,7 +284,7 @@ def test_get_log_prefix_with_no_prefix_does_not_raise():
                 ),
             ],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     assert module.get_log_prefix() is None
@@ -299,7 +307,7 @@ def test_set_log_prefix_updates_all_handler_formatters():
                 ),
             ],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     module.set_log_prefix('myprefix')
@@ -322,7 +330,7 @@ def test_set_log_prefix_skips_handlers_without_a_formatter():
                 ),
             ],
             removeHandler=lambda handler: None,
-        )
+        ),
     )
 
     module.set_log_prefix('myprefix')
@@ -447,12 +455,13 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_linux(
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').with_args('/dev/log').and_return(True)
     syslog_handler = logging.handlers.SysLogHandler()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').with_args(
-        address='/dev/log'
+        address='/dev/log',
     ).and_return(syslog_handler).once()
 
     module.configure_logging(logging.INFO, syslog_log_level=logging.DEBUG)
@@ -469,13 +478,14 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_macos(
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').with_args('/dev/log').and_return(False)
     flexmock(module.os.path).should_receive('exists').with_args('/var/run/syslog').and_return(True)
     syslog_handler = logging.handlers.SysLogHandler()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').with_args(
-        address='/var/run/syslog'
+        address='/var/run/syslog',
     ).and_return(syslog_handler).once()
 
     module.configure_logging(logging.INFO, syslog_log_level=logging.DEBUG)
@@ -492,14 +502,15 @@ def test_configure_logging_with_syslog_log_level_probes_for_log_socket_on_freebs
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').with_args('/dev/log').and_return(False)
     flexmock(module.os.path).should_receive('exists').with_args('/var/run/syslog').and_return(False)
     flexmock(module.os.path).should_receive('exists').with_args('/var/run/log').and_return(True)
     syslog_handler = logging.handlers.SysLogHandler()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').with_args(
-        address='/var/run/log'
+        address='/var/run/log',
     ).and_return(syslog_handler).once()
 
     module.configure_logging(logging.INFO, syslog_log_level=logging.DEBUG)
@@ -515,7 +526,8 @@ def test_configure_logging_without_syslog_log_level_skips_syslog():
     flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.INFO, handlers=list
+        level=logging.INFO,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').never()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').never()
@@ -533,7 +545,8 @@ def test_configure_logging_skips_syslog_if_not_found():
     flexmock(module).should_receive('Multi_stream_handler').and_return(multi_stream_handler)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.INFO, handlers=list
+        level=logging.INFO,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.logging.handlers).should_receive('SysLogHandler').never()
@@ -552,14 +565,17 @@ def test_configure_logging_skips_log_file_if_log_file_logging_is_disabled():
 
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.INFO, handlers=list
+        level=logging.INFO,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').never()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').never()
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').never()
 
     module.configure_logging(
-        console_log_level=logging.INFO, log_file_log_level=logging.DISABLED, log_file='/tmp/logfile'
+        console_log_level=logging.INFO,
+        log_file_log_level=logging.DISABLED,
+        log_file='/tmp/logfile',
     )
 
 
@@ -574,13 +590,14 @@ def test_configure_logging_to_log_file_instead_of_syslog():
 
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').never()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').never()
     file_handler = logging.handlers.WatchedFileHandler('/tmp/logfile')
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').with_args(
-        '/tmp/logfile'
+        '/tmp/logfile',
     ).and_return(file_handler).once()
 
     module.configure_logging(
@@ -602,16 +619,17 @@ def test_configure_logging_to_both_log_file_and_syslog():
 
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').with_args('/dev/log').and_return(True)
     syslog_handler = logging.handlers.SysLogHandler()
     flexmock(module.logging.handlers).should_receive('SysLogHandler').with_args(
-        address='/dev/log'
+        address='/dev/log',
     ).and_return(syslog_handler).once()
     file_handler = logging.handlers.WatchedFileHandler('/tmp/logfile')
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').with_args(
-        '/tmp/logfile'
+        '/tmp/logfile',
     ).and_return(file_handler).once()
 
     module.configure_logging(
@@ -626,7 +644,7 @@ def test_configure_logging_to_log_file_formats_with_custom_log_format():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.ANSWER
     flexmock(module).should_receive('Log_prefix_formatter').with_args(
-        '{message}',  # noqa: FS003
+        '{message}',
     ).once()
     fake_formatter = flexmock()
     flexmock(module).should_receive('Console_color_formatter').and_return(fake_formatter)
@@ -637,20 +655,21 @@ def test_configure_logging_to_log_file_formats_with_custom_log_format():
     flexmock(module).should_receive('interactive_console').and_return(False)
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.DEBUG, handlers=list
+        level=logging.DEBUG,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').with_args('/dev/log').and_return(True)
     flexmock(module.logging.handlers).should_receive('SysLogHandler').never()
     file_handler = logging.handlers.WatchedFileHandler('/tmp/logfile')
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').with_args(
-        '/tmp/logfile'
+        '/tmp/logfile',
     ).and_return(file_handler).once()
 
     module.configure_logging(
         console_log_level=logging.INFO,
         log_file_log_level=logging.DEBUG,
         log_file='/tmp/logfile',
-        log_file_format='{message}',  # noqa: FS003
+        log_file_format='{message}',
     )
 
 
@@ -665,7 +684,8 @@ def test_configure_logging_skips_log_file_if_argument_is_none():
 
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.INFO, handlers=list
+        level=logging.INFO,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').never()
@@ -685,7 +705,8 @@ def test_configure_logging_uses_console_no_color_formatter_if_color_disabled():
 
     flexmock(module).should_receive('flush_delayed_logging')
     flexmock(module.logging).should_receive('basicConfig').with_args(
-        level=logging.INFO, handlers=list
+        level=logging.INFO,
+        handlers=list,
     )
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.logging.handlers).should_receive('WatchedFileHandler').never()
